@@ -5,11 +5,12 @@
  * Content: This file is part of version 2.x of xautolock. It implements
  *          the program's core functions.
  *
- *          Please send bug reports etc. to eyckmans@imec.be.
+ *          Please send bug reports etc. to mce@scarlet.be.
  *
  * --------------------------------------------------------------------------
  * 
- * Copyright 1990,1992-1999,2001-2002 by Stefan De Troch and Michel Eyckmans.
+ * Copyright 1990, 1992-1999, 2001-2002, 2004, 2007 by  Stefan De Troch and
+ * Michel Eyckmans.
  * 
  * Versions 2.0 and above of xautolock are available under version 2 of the
  * GNU GPL. Earlier versions are available under other conditions. For more
@@ -157,7 +158,7 @@ queryPointer (Display* d)
           resetTriggers ();
 
 #ifdef __GNUC__
-	default: ; /* Makes gcc -Wall shut up. */
+	default: break; /* Makes gcc -Wall shut up. */
 #endif /* __GNUC__ */
       }
     }
@@ -282,7 +283,7 @@ evaluateTriggers (Display* d)
     *  For the time being, VMS users are out of luck: their xautolock
     *  will indeed block until the killer returns.
     */
-    (void) system (killer);
+    { int dummy; dummy = system (killer); } // Silly gcc...
     setKillTrigger (killTime);
   }
 
@@ -298,7 +299,7 @@ evaluateTriggers (Display* d)
      /*
       *  Here we use the same dirty trick as for the killer command.
       */
-      (void) system (notifier);
+      { int dummy; dummy = system (notifier); } // Silly gcc...
     }
     else
     {
@@ -341,7 +342,7 @@ evaluateTriggers (Display* d)
 #endif /* SLOW_VMS */
 #else /* VMS */
           (void) execl ("/bin/sh", "/bin/sh", "-c", 
-	                (lockNow ? nowLocker : locker), 0);
+	                (lockNow ? nowLocker : locker), (void*) 0);
 #endif /* VMS */
           _exit (EXIT_FAILURE);
   
