@@ -6,11 +6,12 @@
  *          the program's main() function as well as some boring X related
  *          chit-chat.
  *
- *          Please send bug reports etc. to eyckmans@imec.be.
+ *          Please send bug reports etc. to mce@scarlet.be.
  *
  * --------------------------------------------------------------------------
  *
- * Copyright 1990,1992-1999,2001-2002 by Stefan De Troch and Michel Eyckmans.
+ * Copyright 1990, 1992-1999, 2001-2002, 2004, 2007 by  Stefan De Troch and
+ * Michel Eyckmans.
  *
  * Versions 2.0 and above of xautolock are available under version 2 of the
  * GNU GPL. Earlier versions are available under other conditions. For more
@@ -96,6 +97,7 @@ int
 main (int argc, char* argv[])
 {
   Display* d;
+  time_t   t0, t1;
   Bool     useMit = False;
   Bool     useXidle = False;
 
@@ -133,6 +135,8 @@ main (int argc, char* argv[])
   (void) XSetErrorHandler ((XErrorHandler) catchFalseAlarm);
   (void) XSync (d, 0);
 
+  t0 = time (NULL);
+
 
  /*
   *  Main event loop.
@@ -154,6 +158,13 @@ main (int argc, char* argv[])
     evaluateTriggers (d);
 
     (void) sleep (1);
+
+    if (detectSleep)
+    {
+      t1 = time (NULL);
+      if ((unsigned long) t1 - (unsigned long) t0 > 3) resetLockTrigger ();
+      t0 = t1;
+    }
   }
 
   return 0; /* Never reached! */
